@@ -1,4 +1,3 @@
-
 # -*- coding: utf-8 -*-
 """
 作者：　terrychan
@@ -8,3 +7,5 @@ Blog: https://terrychan.org
 """
 
 from .AutoClear import AutoClear
+from .BIO import *
+from .fun import *
